==> portal-contribuinte-3.249.0.zip: BOOT-INF/classes/sql/simam/conferencia/ArrecadacaoPorTipoCredito.sql <==
select 13                                             							as codigoArquivo,
       'Arrecadação por Tipo de Crédito' 							            as arquivo,
       'CREDITO'                                      							as tipoArquivo,
       arquivo.valor                         	                                as valorArquivo,
       integracao.valor                               							as valorIntegracao,
       retencao.valor                                                           as valorRetencao,
       (select
        case when count(teis.idregistro) > 0 then 'true' else 'false' end
        from tcearrecadacaotipocredito atc
        join triberrosimportacaosimam teis on
        teis.idregistro = atc.idtcearrtipocredito
        and teis.identificadorarquivo = 'ARRECADACAO_TIPO_CREDITO'
        where atc.nrmes = :mes and atc.nrano = :ano) as temerroimportacao
from (select coalesce(sum(atc.vlarrecadacao),0) as valor
      from tceArrecadacaoTipoCredito atc
      where atc.nrmes = :mes and atc.nrano = :ano) arquivo
         cross join (select sum(liic.valortributo - liic.valordeducao) as valor
                     from loteintegracaocontabil lic
                              left join loteitemintegracaocontabil liic
                                        on lic.id = liic.idlote
                              left join tribreceita tr on liic.idtributo = tr.id
                              left JOIN tribreceitatipo trt ON trt.tiporeceita = tr.tiporeceita
                     where lic.datalote between :dataInicial and :dataFinal
                       and trt.classificacaoreceitatipo IN (1, 2, 3, 4, 5, 7)
                       and lic.situacaointegracaocontabil != 'ESTORNADO_CONTABILIDADE'
                       and (lic.tipolote in ('PAGAMENTO', 'REABILITACAO_PAGAMENTO') or (lic.tipolote = 'RESTITUICAO'))) integracao
         cross join (select coalesce(sum(rc.valor),0) as valor from tceretencaocontabil rc
                     where rc.dtlancamento between :dataInicial and :dataFinal and coalesce(rc.devolucao, 'N') = 'N') retencao

==> portal-contribuinte-3.317.1.zip: BOOT-INF/classes/sql/simam/conferencia/ArrecadacaoPorTipoCredito.sql <==
select 13                                             							as codigoArquivo,
       'Arrecadação por Tipo de Crédito' 							            as arquivo,
       'CREDITO'                                      							as tipoArquivo,
       arquivo.valor                         	                                as valorArquivo,
       integracao.valor                               							as valorIntegracao,
       retencao.valor                                                           as valorRetencao,
       (select
        case when count(teis.idregistro) > 0 then 'true' else 'false' end
        from tcearrecadacaotipocredito atc
        join triberrosimportacaosimam teis on
        teis.idregistro = atc.idtcearrtipocredito
        and teis.identificadorarquivo = 'ARRECADACAO_TIPO_CREDITO'
        where atc.nrmes = :mes and atc.nrano = :ano) as temerroimportacao,
        (select case when count(atc.idtcearrtipocredito) > 0 then 'true' else 'false' end
         from tcearrecadacaotipocredito atc
                where atc.nrmes = :mes and atc.nrano = :ano
                and (((atc.nrcredito is null or atc.nranocredito is null) and atc.idtipoorigemreceita = 1) or
                     ((atc.nrdivida is null or atc.nranodivida is null) and atc.idtipoorigemreceita > 1)
                )) as temerronrcreditodivida
from (select coalesce(sum(atc.vlarrecadacao),0) as valor
      from tceArrecadacaoTipoCredito atc
      where atc.nrmes = :mes and atc.nrano = :ano) arquivo
         cross join (select sum(liic.valortributo - liic.valordeducao) as valor
                     from loteintegracaocontabil lic
                              left join loteitemintegracaocontabil liic
                                        on lic.id = liic.idlote
                              left join tribreceita tr on liic.idtributo = tr.id
                              left JOIN tribreceitatipo trt ON trt.tiporeceita = tr.tiporeceita
                     where lic.datalote between :dataInicial and :dataFinal
                       and trt.classificacaoreceitatipo IN (1, 2, 3, 4, 5, 7)
                       and lic.situacaointegracaocontabil != 'ESTORNADO_CONTABILIDADE'
                       and (lic.tipolote in ('PAGAMENTO', 'REABILITACAO_PAGAMENTO') or (lic.tipolote = 'RESTITUICAO'))) integracao
         cross join (select coalesce(sum(rc.valor),0) as valor from tceretencaocontabil rc
                     where rc.dtlancamento between :dataInicial and :dataFinal and coalesce(rc.devolucao, 'N') = 'N') retencao
